function [MFS, ALPHA] = Momentmfs(im,ite_num)


%%Estimate the MFS vector for im using the moment-based method
%Output:  MFS    <---- The mfs of the image im
%         ALPHA  <---- The corresponding density index

%Input:  im      ---> The image
%        ite_num ---> The radius
%Author: Yong Xu, Hui Ji
%Last modified: Oct 10, 2007.

if (length(size(im)) == 3),
    display('Warning: Only works on grayscale image, converted to grayscale image');
    im = rgb2gray(im);
end;


%% Using [1..256] to denote the intensity profile of the image
GRAY_BOUND =[1, 256];

%% Preprocessing: default intensity value of image ranges from 1 to 256
im = double(im);
im = GRAY_BOUND(1)+ (GRAY_BOUND(2)-GRAY_BOUND(1))...
    * (im - min(im(:)))/(max(im(:))-min(im(:)));

%% The default range for q =[b:c:d]
b=-4;
c=0.1;
d=8.1;

RESOL = max(size(im));
for k = 1:ite_num,
    r(k) = log10(RESOL/k);
end;
rrr = mean(r);
    
M=cell(1,ite_num);
for k = 1:ite_num,
    M{k} = conv2(im, ones(k,k),'same');
    M{k} = M{k}(max(k-1,1):k:end,max(k-1,1):k:end);
end;

for qq = b:c:d,
     p=int32((qq-b)/c+1);
     km = zeros(1,ite_num);
     for k = 1:ite_num,
         km(k) = log10(sum(M{k}(:).^qq));
     end; 
     mmm = mean(km);
     B(p) =  sum((km-mmm).*(r-rrr)) ./ sum((r-rrr).^2);
end;
     
    




%% Using Legendre transform to estimate MFS
q = [b:c:d];
Beta=B;
aq = conv2(Beta,[-1/2, 0, 1/2],'same');
aq = aq(2:end-1)/c;
beta = Beta(2:end-1);
q = q(2:end-1);
fq = q .* aq + beta;
[junk,idx]=sort(aq(:));
aq(:)=aq(idx);
fq(:)=fq(idx);

idx = find(((fq>=0)+(fq<=2))==2);
MFS = fq(idx);
ALPHA = aq(idx);
%cputime-t 



        
    
        
    
