function MFS_Combined = mfsALL(IM,varargin) 
%mfsAll Computes combined  MFS measurements consisting  of three kinds: 
%Density (Intensity),  Gradients, Laplacian.
%
%mfsAll(IM) computes the MFS vectors for three kinds of measurements
%   1)  Density (Intensity)
%   2)  Gradients
%   3)  Laplacian
%
%MFS_Combined = mfsAll(IM) returns the vector including three types of MFS
%                          for input image IM
%
%
%Author: Yong Xu, Hui Ji
%Date: Apr 24, 2007
%
% parameters are : image, ind_num, f_num, ite_num

switch nargin,
    case 2,
        ind_num = varargin{1};  % density counting level for density, choose 1 (only intesity) or 8 (density)
        f_num = 26;  % dimension of MFS
        ite_num = 8; % iteration levels in estimating fractal dimension
    case 3,
        ind_num = varargin{1};
        f_num = varargin{2};
        ite_num = 8;
    case 4,    
        ind_num = varargin{1};
        f_num = varargin{2};
        ite_num = varargin{3};
    otherwise,
        %%%% On density from intensity %%%%
        ind_num = 8; %density counting levels
        f_num = 26;  %the dimension of MFS
        ite_num = 8; %Box counting levels   
        
        %%%% Directly on intensity or high-level image measurements %%%%
        % ind_num = 1;
        % f_num = 26;
        % ite_num =3;
end;
% switch nargin,
%     case 2,
%         ite_num = 8; %Box counting level
%         ind_num = 8; %density counting level for density
%         f_num = varargin{1};  %The dimension of MFS
%     case 3,
%         ind_num = 8;
%         f_num = varargin{1};
%         ite_num = varargin{2};
%     case 4,
%         f_num = varargin{1};
%         ite_num = varargin{2};
%         ind_num = varargin{3};
%     otherwise,
%         %% On density from intensity
%         ind_num = 8; %density counting levels
%         f_num = 26;  %the dimension of MFS
%         ite_num = 8; %Box counting levels   
%         
%         %% Directly on intensity or high-level image measurements
%         % ind_num = 1;
%         % f_num = 26;
%         % ite_num =3;
% end;

% Preprocessing 
if (length(size(IM)) == 3),
    IM = rgb2gray(IM);
end;
IM = double(IM);

%Compute Intensity
W = sum(double(IM(:)));

%Compute Gradient

fx = 1/2*[-1 0 1];
fy = fx';
fxy = 1/2*[-1 0 0;0 0 0;0 0 1];
fyx = 1/2*[0 0 -1;0 0 0;1 0 0]; 

IMG = single(IM);
IMG = (conv2(IMG,fx,'same')).^2 + (conv2(IMG,fy,'same')).^2 ...
    +(conv2(IMG,fxy,'same')).^2 +(conv2(IMG,fyx,'same')).^2;
IMG = sqrt(IMG);
IMG = uint8(fix(IMG)); 

WG = sum(double(IMG(:)));

%Compute Laplacian

f1 = fspecial('gaussian',5,1); 
f2 = [-1 -1 -1;-1 8 -1;-1 -1 -1];
f = conv2(f1,f2);  

IML = single(IM);
IML = conv2(single(IML),f,'same');
IML = uint8(fix(IML)); 

WL = sum(double(IML(:)));

%% MFS of Density
im = double(IM);
im = im * W /sum(im(:));
m = Densitymfs(im,ind_num, f_num, ite_num);

%% MFS of Gradient

imG = single(IM);
imG = (conv2(imG,fx,'same')).^2 + (conv2(imG,fy,'same')).^2 + ...
    (conv2(imG,fxy,'same')).^2 + (conv2(imG,fyx,'same')).^2;
imG = sqrt(imG);
imG = uint8(fix(imG)); 

imG = double(imG);
imG = imG * WG /sum(imG(:));
mG = Densitymfs(imG,1, f_num, ite_num);

%% MFS of Laplacion

imL = single(im);
imL = conv2(single(imL),f,'same');
imL = uint8(fix(imL)); 

imL = double(imL);
imL = imL * WL /sum(imL(:));
mL = Densitymfs(imL,1, f_num, ite_num);

%% Comine all three vector 

MFS_Combined = [m'; mG'; mL']; 

